[vlc-devel] [PATCH 1/1] ts: don't drop entire audio frame on discontinuity

Tristan Matthews le.businessman at gmail.com
Tue Sep 30 05:36:38 CEST 2014


Refs #11752
---
 modules/demux/ts.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/modules/demux/ts.c b/modules/demux/ts.c
index 10c08fa..3216cb7 100644
--- a/modules/demux/ts.c
+++ b/modules/demux/ts.c
@@ -2457,9 +2457,10 @@ static bool GatherData( demux_t *p_demux, ts_pid_t *pid, block_t *p_bk )
                       i_cc, ( pid->i_cc + 1 )&0x0f, pid->i_pid );
 
             pid->i_cc = i_cc;
-            if( pid->es->p_data && pid->es->fmt.i_cat != VIDEO_ES )
+            if( pid->es->p_data && pid->es->fmt.i_cat != VIDEO_ES &&
+                pid->es->fmt.i_cat != AUDIO_ES)
             {
                 /* Small video artifacts are usually better than
                  * dropping full frames */
                 pid->es->p_data->i_flags |= BLOCK_FLAG_CORRUPTED;
             }
@@ -2457,9 +2457,10 @@ static bool GatherData( demux_t *p_demux, ts_pid_t *pid, block_t *p_bk )
             {
-                /* Small video artifacts are usually better than
+                /* Small audio/video artifacts are usually better than
                  * dropping full frames */
                 pid->es->p_data->i_flags |= BLOCK_FLAG_CORRUPTED;
-- 
1.9.1




More information about the vlc-devel mailing list